==> tdf?file=1&path=frealign_v8.11_130826.tar.gz: frealign_v8.11/src/cards8and9.f <==
C**************************************************************************
      SUBROUTINE CARDS8AND9(NSET,MAXSET,FINPAT1,FINPAT2,
     .			INPROJ,CFORM,ASYM,
     .		        PSIZE,VX,NSAM,ICMP,RLIM,RMM,
     .			RMAX1,RMAX2,RREC,RI,MSIZE)
C**************************************************************************
C Read input cards 8 and 9 
C  Card 8      FINPAT1 - PARTICLE IMAGE STACK FILENAME
C  Card 9      FINPAT2 - MATCHING PROJECTIONS STACK (for O/P if FMATCH=T)
C Calls IOPEN and ICLOSE.
C Called by Frealign.
C*************************************************************************
      IMPLICIT NONE
      INTEGER N2,NSTACK,MSIZE
      INTEGER NSET,INPROJ
      INTEGER NSAM,MAXSET,ICMP
      REAL RLIM,RMM,RTEMP,RI
      REAL PSIZE,PSIZE1
      REAL RREC(*),RMAX1(*),RMAX2(*)
      CHARACTER*3 ASYM
      CHARACTER*15 VX
      CHARACTER CFORM
      CHARACTER*200 FINPAT,FINPAT1(*),FINPAT2(*)
C**************************************************************************
        WRITE(*,*)' PARTICLE IMAGE STACK ?'
        READ(*,7006) FINPAT1(NSET)
        WRITE(*,17006) FINPAT1(NSET)
        IF (NSET.EQ.1) THEN
          CALL IOPEN(FINPAT1(NSET),INPROJ,CFORM,NSAM,N2,NSTACK,
     +                'OLD',ASYM,PSIZE1,VX)
          CALL ICLOSE(INPROJ)
          IF (2*(NSAM/2).NE.NSAM) THEN
            STOP ' Particle dimensions must be even!!!'
          ENDIF
          IF (NSAM.NE.N2) THEN
            STOP ' Particle dimensions must be the same in X and Y!'
          ENDIF
        ENDIF
C       check and convert resolution from Angstroms to reciprocal fraction
        IF(RMAX1(NSET).LT.RMAX2(NSET)) THEN     ! swap
                        RTEMP=RMAX1(NSET)
                        RMAX1(NSET)=RMAX2(NSET)
                        RMAX2(NSET)=RTEMP
        ENDIF
        IF(RREC(NSET).LT.1.2.OR.RREC(NSET).GT.100.0) STOP 'RES?'
        IF(RMAX1(NSET).LT.10.0.OR.RMAX1(NSET).GT.1000.0) STOP 'RES?'
        IF(RMAX2(NSET).LT.2.0.OR.RMAX2(NSET).GT.200.0) STOP 'RES?'
        RREC(NSET)=PSIZE/RREC(NSET)
        IF (RREC(NSET).GT.0.5) RREC(NSET)=0.5
C        RLIM=RREC(NSET)-2.0/NSAM
        RLIM=RREC(NSET)
        RMAX1(NSET)=PSIZE/RMAX1(NSET)
        RMAX2(NSET)=PSIZE/RMAX2(NSET)
C        IF (RREC(NSET).GT.RLIM) RLIM=RREC(NSET)   ! highest resolution of datasets
        IF (RMAX2(NSET).GT.RLIM) RMAX2(NSET)=RLIM
        IF (RMAX2(NSET).GT.RMM) RMM=RMAX2(NSET)   ! only used if DANGIN not set
        ICMP=3.0*RI/MSIZE
        IF (3.0*RI.GT.NSAM) ICMP=NSAM/MSIZE
        IF (ICMP.EQ.0) ICMP=1
C
C        IF (FMATCH) THEN
C now always read in
          WRITE(*,*)' MATCHING PROJECTIONS IMAGE STACK ?'
          READ(*,7006) FINPAT2(NSET)
          WRITE(*,17006) FINPAT2(NSET)
C        ENDIF
7006            FORMAT(A200)
17006           FORMAT(3X,A200)
	RETURN
	END

==> tdf?file=1&path=frealign_v9.05_131002.tar.gz: frealign_v9.05/src/cards8and9.f <==
C*
C* Copyright 2013 Howard Hughes Medical Institute.
C* All rights reserved.
C* Use is subject to Janelia Farm Research Campus Software Copyright 1.1
C* license terms ( http://license.janelia.org/license/jfrc_copyright_1_1.html )
C*
C**************************************************************************
      SUBROUTINE CARDS8AND9(NSET,MAXSET,FINPAT1,FINPAT2,
     .			INPROJ,CFORM,ASYM,
     .		        PSIZE,VX,NSAM,ICMP,RLIM,RMM,
     .			RMAX1,RMAX2,RREC,RI,MSIZE)
C**************************************************************************
C Read input cards 8 and 9 
C  Card 8      FINPAT1 - PARTICLE IMAGE STACK FILENAME
C  Card 9      FINPAT2 - MATCHING PROJECTIONS STACK (for O/P if FMATCH=T)
C Calls IOPEN and ICLOSE.
C Called by Frealign.
C*************************************************************************
      IMPLICIT NONE
C
      INTEGER N2,NSTACK,NSET,INPROJ,MSIZE
      INTEGER NSAM,MAXSET,ICMP,SLEN2
      REAL RLIM,RMM,RTEMP,RI
      REAL PSIZE,PSIZE1
      REAL RREC(*),RMAX1(*),RMAX2(*)
      CHARACTER*3 ASYM
      CHARACTER*15 VX
      CHARACTER CFORM
      CHARACTER*200 FINPAT,FINPAT1(*),FINPAT2(*)
C**************************************************************************
        WRITE(*,*)' PARTICLE IMAGE STACK ?'
        READ(*,7006) FINPAT1(NSET)
        WRITE(*,17006) FINPAT1(NSET)(1:SLEN2(FINPAT1(NSET)))
        IF (NSET.EQ.1) THEN
          CALL IOPEN(FINPAT1(NSET),INPROJ,CFORM,NSAM,N2,NSTACK,
     +                'OLD',ASYM,PSIZE1,VX)
          CALL ICLOSE(INPROJ)
          IF (2*(NSAM/2).NE.NSAM) THEN
            STOP ' Particle dimensions must be even!!!'
          ENDIF
          IF (NSAM.NE.N2) THEN
            STOP ' Particle dimensions must be the same in X and Y!'
          ENDIF
        ENDIF
C       check and convert resolution from Angstroms to reciprocal fraction
        IF(RMAX1(NSET).LT.RMAX2(NSET)) THEN     ! swap
                        RTEMP=RMAX1(NSET)
                        RMAX1(NSET)=RMAX2(NSET)
                        RMAX2(NSET)=RTEMP
        ENDIF
        IF(RREC(NSET).LT.2.0.OR.RREC(NSET).GT.100.0) STOP 'RES?'
        IF(RMAX1(NSET).LT.10.0.OR.RMAX1(NSET).GT.1000.0) STOP 'RES?'
        IF(RMAX2(NSET).LT.2.0.OR.RMAX2(NSET).GT.200.0) STOP 'RES?'
        RREC(NSET)=PSIZE/RREC(NSET)
        IF (RREC(NSET).GT.0.5) RREC(NSET)=0.5
        RLIM=RREC(NSET)-2.0/NSAM
        RMAX1(NSET)=PSIZE/RMAX1(NSET)
        RMAX2(NSET)=PSIZE/RMAX2(NSET)
C        IF (RREC(NSET).GT.RLIM) RLIM=RREC(NSET)   ! highest resolution of datasets
        IF (RMAX2(NSET).GT.RLIM) RMAX2(NSET)=RLIM
        IF (RMAX2(NSET).GT.RMM) RMM=RMAX2(NSET)   ! only used if DANGIN not set
        ICMP=3.0*RI/MSIZE
        IF (3.0*RI.GT.NSAM) ICMP=NSAM/MSIZE
        IF (ICMP.EQ.0) ICMP=1
C
C        IF (FMATCH) THEN
C now always read in
          WRITE(*,*)' MATCHING PROJECTIONS IMAGE STACK ?'
          READ(*,7006) FINPAT2(NSET)
          WRITE(*,17006) FINPAT2(NSET)(1:SLEN2(FINPAT2(NSET)))
C        ENDIF
7006            FORMAT(A200)
17006           FORMAT(3X,A)
	RETURN
	END
